package com.microchip.esdev.dbas.web;

import com.vaadin.annotations.Theme;
import com.vaadin.server.ThemeResource;
import com.vaadin.server.VaadinRequest;
import com.vaadin.spring.annotation.SpringUI;
import com.vaadin.ui.Tree;
import com.vaadin.ui.UI;
import com.vaadin.ui.VerticalLayout;

@SuppressWarnings("serial")
@SpringUI
@Theme("dbas")
public class TreeUI extends UI {

	private Tree theTree;
	@Override
	protected void init(VaadinRequest request) {
		VerticalLayout content = new VerticalLayout();
		setContent(content);
		
		theTree = new Tree();
		TreeNode root = new TreeNode("DBAS",TREE_TYPE.ROOT);
		addNodeToTree(root,null,false);
		
		TreeNode job = new TreeNode("Default",TREE_TYPE.JOB);
		addNodeToTree(job,root,false);
		addNodeToTree(new TreeNode("Extract",TREE_TYPE.EXTRACT),job,true);
		addNodeToTree(new TreeNode("Parameter Definition",TREE_TYPE.PARAMETER),job,true);
		
		TreeNode analysisRoot = new TreeNode("Analysis",TREE_TYPE.ANALYSISROOT);				
		addNodeToTree(analysisRoot,job,false);
		
		TreeNode plotAna = new TreeNode("PPLOT",TREE_TYPE.PLOT);
		addNodeToTree(plotAna,analysisRoot,false);
		addNodeToTree(new TreeNode("[S1] - Test Yield",TREE_TYPE.PLOT),plotAna,true);
		addNodeToTree(new TreeNode("[S2] - Test Yield",TREE_TYPE.PLOT),plotAna,true);
		
		addNodeToTree(new TreeNode("Trend",TREE_TYPE.PLOT),analysisRoot,true);
		
        for (Object itemId: theTree.getItemIds())
        	theTree.expandItem(itemId);
		
		content.addComponent(theTree);
		content.setSizeFull();
	}
	
	private void addNodeToTree(TreeNode child,TreeNode parent,boolean bLeaf)
	{
		theTree.addItem(child);		
		if(parent != null)
			theTree.setParent(child, parent);			
		if(bLeaf)
			theTree.setChildrenAllowed(child, false);
        switch(child.getTreeNodeType())
        {
	        case ROOT:
	        {
	        	theTree.setItemIcon(child, new ThemeResource("img/root.gif"));;
	        }
	        break;
	        case JOB:
	        {
	        	theTree.setItemIcon(child, new ThemeResource("img/close.gif"));;
	        }
	        break;
	        case EXTRACT:
	        {
	        	theTree.setItemIcon(child, new ThemeResource("img/extract.gif"));;
	        }
	        break;
	        case PARAMETER:
	        {
	        	theTree.setItemIcon(child, new ThemeResource("img/paramdef.gif"));;
	        }
	        break;
	        case ANALYSISROOT:
	        {
	        	theTree.setItemIcon(child, new ThemeResource("img/analysis.gif"));;
	        }
	        break;
	        case PLOT:
	        {
	        	theTree.setItemIcon(child, new ThemeResource("img/report.gif"));;
	        }
	        break;
        }
	}

}
